@@ -1,6 +1,7 @@
 import argparse
 import sys
 from qrunner import __version__, __description__
+from qrunner.scaffold import init_parser_scaffold, main_scaffold
 
 
 def main():
@@ -11,7 +12,8 @@ def main():
         "-V", "--version", dest="version", action="store_true", help="show version"
     )
 
-    # subparsers = parser.add_subparsers(help="sub-command help")
+    subparsers = parser.add_subparsers(help="sub-command help")
+    sub_parser_scaffold = init_parser_scaffold(subparsers)
 
     if len(sys.argv) == 1:
         # qrunner
@@ -28,6 +30,9 @@ def main():
         # elif sys.argv[1] == "startproject":
         #     # httprunner startproject
         #     sub_parser_scaffold.print_help()
+        elif sys.argv[1] == "startproject":
+            # httprunner startproject
+            sub_parser_scaffold.print_help()
         sys.exit(0)
 
     args = parser.parse_args()
@@ -35,6 +40,9 @@ def main():
         print(f"{__version__}")
         sys.exit(0)
 
+    if sys.argv[1] == "startproject":
+        main_scaffold(args)
+
 
 if __name__ == "__main__":
     main()
