@@ -2,8 +2,8 @@ import os
 import time
 import allure
 import uiautomator2 as u2
-from utils.log import logger
-from utils.config import conf
+from qrunner.utils.log import logger
+from conf.config import conf
 
 
 class Driver(object):
