@@ -1,6 +1,6 @@
 import time
-from utils.log import logger
-from core.android.driver import Driver
+from qrunner.utils.log import logger
+from qrunner.core.android.driver import Driver
 
 
 # 初始化driver
