@@ -7,9 +7,9 @@ import allure
 import requests
 import wda
 
-from utils.log import logger
-from utils.config import conf
-from core.ios.wda_server import WDAServer
+from qrunner.utils.log import logger
+from conf.config import conf
+from qrunner.core.ios.wda_server import WDAServer
 
 
 # 重启wda的装饰器
