@@ -1,6 +1,6 @@
 import os
 import subprocess
-from utils.log import logger
+from qrunner.utils.log import logger
 
 
 class ChromeServer:
